==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/kombilimits_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists kombilimits_au//
create trigger kombilimits_au after update on kombilimits
  for each row 
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, newvalues)
  select NEW.serverID, NEW.accessID, 'kombilimits', NEW.ID, NEW.autokombilimitsID,
    NEW.groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name,
    concat('expression=', REPLACE(REPLACE(NEW.expression, '\\', '\\\\'), '\n', '\\n'), '\nrelation=', NEW.relation, '\ninfolevel=',
           NEW.infolevel, '\nwarnlevel=', NEW.warnlevel, '\nerrorlevel=', NEW.errorlevel,
           '\nnotifymode=', NEW.notifymode, '\nmessage=',
           REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'), '\ndestination1=', notifdestname(NEW.meldungszielID),
           '\ndestination2=', notifdestname(NEW.meldungsziel2ID), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''),
           if(NEW.groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(NEW.autokombilimitsID > OLD.autokombilimitsID, '\nconverted to domain-auto', ''))
  from server, section, teststep
  where NEW.TS != OLD.TS and server.ID = NEW.serverID and section.ID = NEW.sectionID
    and teststep.ID = NEW.teststepID;
end//


drop trigger if exists kombilimits_ai//
create trigger kombilimits_ai after insert on kombilimits
  for each row 
begin
  insert into tkombilimits (ID) select NEW.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, newvalues)
  select NEW.serverID, NEW.accessID, 'kombilimits', NEW.ID, NEW.autokombilimitsID,
    NEW.groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name,
    concat('expression=', REPLACE(REPLACE(NEW.expression, '\\', '\\\\'), '\n', '\\n'), '\nrelation=', NEW.relation, '\ninfolevel=',
           NEW.infolevel, '\nwarnlevel=', NEW.warnlevel, '\nerrorlevel=', NEW.errorlevel,
           '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID),
           '\ndestination2=', notifdestname(NEW.meldungsziel2ID), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''))
  from server, section, teststep
  where server.ID = NEW.serverID and section.ID = NEW.sectionID
    and teststep.ID = NEW.teststepID;
end//


drop trigger if exists kombilimits_bd//
create trigger kombilimits_bd before delete on kombilimits
  for each row 
begin
  delete from tkombilimits where tkombilimits.ID = OLD.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, newvalues)
  select OLD.serverID, OLD.accessID, 'kombilimits', OLD.ID,
    OLD.autokombilimitsID, OLD.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name,
    coalesce(if(OLD.bemerkungen = @combilimitsremark, '', concat('remark=', REPLACE(REPLACE(@combilimitsremark, '\\', '\\\\'), '\n', '\\n'))),'')
  from server, section, teststep
  where server.ID = OLD.serverID and section.ID = OLD.sectionID
    and teststep.ID = OLD.teststepID;
end//


delimiter ;

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/kombilimits_trigger.sql <==
set @@character_set_client = 'utf8';

delimiter //

drop trigger if exists kombilimits_au//
create trigger kombilimits_au after update on kombilimits
  for each row
begin
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, newvalues)
  select serverID, accessID, 'kombilimits', kombilimits.ID, autokombilimitsID,
    groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'update',
    servername, section.name, teststep.name,
    concat('expression=', REPLACE(REPLACE(expression, '\\', '\\\\'), '\n', '\\n'), '\nrelation=', relation, '\ninfolevel=',
           infolevel, '\nwarnlevel=', warnlevel, '\nerrorlevel=', errorlevel,
           '\nnotifymode=', notifymode, '\nmessage=',
           REPLACE(REPLACE(meldung, '\\', '\\\\'), '\n', '\\n'), '\ndestination1=', notifdestname(meldungszielID),
           '\ndestination2=', notifdestname(meldungsziel2ID), '\nremark=',
           REPLACE(REPLACE(bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', aktiv,
           if(hidden, '\n[hidden]', ''),
           if(groupautoID > OLD.groupautoID, '\nconverted to group-auto', ''),
           if(autokombilimitsID > OLD.autokombilimitsID, '\nconverted to domain-auto', ''))
  from kombilimits
  join server on server.ID = serverID
  join section on section.ID = sectionID
  join teststep on teststep.ID = teststepID
  where kombilimits.ID = NEW.ID and kombilimits.TS = NEW.TS;
end//


drop trigger if exists kombilimits_ai//
create trigger kombilimits_ai after insert on kombilimits
  for each row
begin
  insert into tkombilimits (ID) select NEW.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, newvalues)
  select NEW.serverID, NEW.accessID, 'kombilimits', NEW.ID, NEW.autokombilimitsID,
    NEW.groupautoID, coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'insert',
    servername, section.name, teststep.name,
    concat('expression=', REPLACE(REPLACE(NEW.expression, '\\', '\\\\'), '\n', '\\n'), '\nrelation=', NEW.relation, '\ninfolevel=',
           NEW.infolevel, '\nwarnlevel=', NEW.warnlevel, '\nerrorlevel=', NEW.errorlevel,
           '\nnotifymode=', NEW.notifymode, '\nmessage=', REPLACE(REPLACE(NEW.meldung, '\\', '\\\\'), '\n', '\\n'),
           '\ndestination1=', notifdestname(NEW.meldungszielID),
           '\ndestination2=', notifdestname(NEW.meldungsziel2ID), '\nremark=',
           REPLACE(REPLACE(NEW.bemerkungen, '\\', '\\\\'), '\n', '\\n'), '\nactive=', NEW.aktiv,
           if(NEW.hidden, '\n[hidden]', ''))
  from server, section, teststep
  where server.ID = NEW.serverID and section.ID = NEW.sectionID
    and teststep.ID = NEW.teststepID;
end//


drop trigger if exists kombilimits_bd//
create trigger kombilimits_bd before delete on kombilimits
  for each row
begin
  delete from tkombilimits where tkombilimits.ID = OLD.ID;
  insert into changeprot
    (serverID, accessID, changedtable, tableID, domautoID, groupautoID,
     userID, username, action, server, section, teststep, newvalues)
  select OLD.serverID, OLD.accessID, 'kombilimits', OLD.ID,
    OLD.autokombilimitsID, OLD.groupautoID,
    coalesce(@userid,0), coalesce(@username,'SYSTEM'), 'delete',
    servername, section.name, teststep.name,
    coalesce(if(OLD.bemerkungen = @combilimitsremark, '', concat('remark=', REPLACE(REPLACE(@combilimitsremark, '\\', '\\\\'), '\n', '\\n'))),'')
  from server, section, teststep
  where server.ID = OLD.serverID and section.ID = OLD.sectionID
    and teststep.ID = OLD.teststepID;
end//


delimiter ;
